@@ -11,7 +11,12 @@ test_that("custom RA yields inputs",{
   prob <- declaration_2$probabilities_matrix
   expect_equal(dim(prob), c(10,4))
   
-  Z <- declaration_2$ra_function()
+  Z <- conduct_ra(declaration_2)
+  
+  expect_identical(
+    permutation_matrix,
+    obtain_permutation_matrix(declaration_2)
+  )
   
   expect_identical(
     obtain_condition_probabilities(declaration = declaration_2, assignment = Z),
@@ -20,7 +25,7 @@ test_that("custom RA yields inputs",{
   )
     
     
-  expect_identical(
+  expect_equal(
     obtain_num_permutations(declaration_2),
     ncol(permutation_matrix)
   )
